==> App-GitHooks-Plugin-PerlCompile-v1.0.0.tar.gz: App-GitHooks-Plugin-PerlCompile-v1.0.0/README.md <==
App-GitHooks-Plugin-PerlCompile
===============================

[![Build Status](https://travis-ci.org/guillaumeaubert/App-GitHooks-Plugin-PerlCompile.png?branch=master)](https://travis-ci.org/guillaumeaubert/App-GitHooks-Plugin-PerlCompile)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/App-GitHooks-Plugin-PerlCompile/badge.png?branch=master)](https://coveralls.io/r/guillaumeaubert/App-GitHooks-Plugin-PerlCompile?branch=master)

App::GitHooks plugin to verify that Perl files compile without errors.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc App::GitHooks::Plugin::PerlCompile


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/App-GitHooks-Plugin-PerlCompile/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/App-GitHooks-Plugin-PerlCompile)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/App-GitHooks-Plugin-PerlCompile)

 * [MetaCPAN]
   (https://metacpan.org/release/App-GitHooks-Plugin-PerlCompile)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2013-2014 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/

==> App-GitHooks-Plugin-PerlCompile-v1.0.2.tar.gz: App-GitHooks-Plugin-PerlCompile-v1.0.2/README.md <==
App-GitHooks-Plugin-PerlCompile
===============================

[![Build Status](https://travis-ci.org/guillaumeaubert/App-GitHooks-Plugin-PerlCompile.svg?branch=master)](https://travis-ci.org/guillaumeaubert/App-GitHooks-Plugin-PerlCompile)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/App-GitHooks-Plugin-PerlCompile/badge.svg?branch=master)](https://coveralls.io/r/guillaumeaubert/App-GitHooks-Plugin-PerlCompile?branch=master)
[![Latest Version](https://img.shields.io/github/tag/guillaumeaubert/App-GitHooks-Plugin-PerlCompile.svg?style=flat)](https://metacpan.org/release/App-GitHooks-Plugin-PerlCompile)

App::GitHooks plugin to verify that Perl files compile without errors.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc App::GitHooks::Plugin::PerlCompile


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/App-GitHooks-Plugin-PerlCompile/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/App-GitHooks-Plugin-PerlCompile)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/App-GitHooks-Plugin-PerlCompile)

 * [MetaCPAN]
   (https://metacpan.org/release/App-GitHooks-Plugin-PerlCompile)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2013-2015 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/
